<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AboutPreferences</name>
    <message>
        <location filename="../src/ui/qml/AboutPreferences.qml" line="14"/>
        <source>Ricochet %1</source>
        <extracomment>%1 version, e.g. 1.0.0</extracomment>
        <translation>Ricochet %1</translation>
    </message>
</context>
<context>
    <name>AddContactDialog</name>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="51"/>
        <source>Share your Ricochet ID to allow connection requests</source>
        <translation>Comparta su ID (identificador) de Ricochet para permitir solicitudes de conexión</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="107"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="112"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
</context>
<context>
    <name>ContactActions</name>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="40"/>
        <source>Open Window</source>
        <translation>Abrir Ventana</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="44"/>
        <source>Details...</source>
        <translation>Detalles...</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="48"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="53"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>ContactIDField</name>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="41"/>
        <source>&lt;b&gt;%1&lt;/b&gt; is already your contact</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ya es su contacto</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="43"/>
        <source>You can&apos;t add yourself as a contact</source>
        <translation>No puede añadirse a usted mismo como un contacto</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="45"/>
        <source>Enter an ID starting with &lt;b&gt;ricochet:&lt;/b&gt;</source>
        <translation>Introduzca un ID comience con &lt;b&gt;ricochet:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="81"/>
        <source>Copied to clipboard</source>
        <translation>Copiado al portapapeles</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="93"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>ContactList</name>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="76"/>
        <source>Online</source>
        <translation>En línea</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="77"/>
        <source>Offline</source>
        <translation>Fuera de línea</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="78"/>
        <source>Requests</source>
        <translation>Solicitudes</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="79"/>
        <source>Rejected</source>
        <translation>Rechazada</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="80"/>
        <source>Outdated</source>
        <translation>Caducada</translation>
    </message>
</context>
<context>
    <name>ContactPreferences</name>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="98"/>
        <source>Date added:</source>
        <translation>Añadido desde:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="106"/>
        <source>Last seen:</source>
        <translation>Visto por última vez:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="116"/>
        <source>Request:</source>
        <translation>Solicitud:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="126"/>
        <source>Pending connection</source>
        <translation>Conexión pendiente</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="127"/>
        <source>Delivered</source>
        <translation>Entregado</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="128"/>
        <source>Accepted</source>
        <translation>Aceptado</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="129"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="130"/>
        <source>Rejected</source>
        <translation>Rechazado</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="134"/>
        <source>%1 (Connected)</source>
        <extracomment>%1 status, e.g. &quot;Accepted&quot;</extracomment>
        <translation>%1 (Conectado)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="140"/>
        <source>Response:</source>
        <translation>Respuesta:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="163"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="170"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>ContactRequestDialog</name>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="55"/>
        <source>Someone new is asking to connect to you</source>
        <translation>Alguien nuevo está pidiendo conectarse con usted</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="102"/>
        <source>Reject</source>
        <translation>Rechazar</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="107"/>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>ContactRequestFields</name>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="17"/>
        <source>ID:</source>
        <translation>ID (identificador):</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="29"/>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="40"/>
        <source>Message:</source>
        <translation>Mensaje:</translation>
    </message>
</context>
<context>
    <name>GeneralPreferences</name>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="13"/>
        <source>Use a single window for conversations</source>
        <translation>Usar una única ventana para conversaciones</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="21"/>
        <source>Open links in default browser without prompting</source>
        <translation>Abrir enlaces en el navegador predeterminado sin pedir confirmación</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="29"/>
        <source>Play audio notifications</source>
        <translation>Reproducir notificaciones de audio</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="38"/>
        <source>Volume</source>
        <translation>Volumen</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="53"/>
        <source>Language</source>
        <translation type="unfinished">Idioma</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="76"/>
        <source>Restart Ricochet to apply changes</source>
        <translation type="unfinished">Reiniciar Ricochet para aplicar los cambios</translation>
    </message>
</context>
<context>
    <name>LanguagePreferences</name>
    <message>
        <source>Select Language</source>
        <translation type="vanished">Seleccionar idioma</translation>
    </message>
    <message>
        <source>Restart Ricochet to apply changes</source>
        <translation type="vanished">Reiniciar Ricochet para aplicar los cambios</translation>
    </message>
</context>
<context>
    <name>LanguagesModel</name>
    <message>
        <location filename="../src/ui/LanguagesModel.cpp" line="43"/>
        <source>System default</source>
        <translation>Predeterminado del sistema</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <source>Ricochet Error</source>
        <translation>Error de Ricochet</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="19"/>
        <source>Add Contact</source>
        <translation>Añadir Contacto</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="28"/>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="75"/>
        <source>Click to add contacts</source>
        <translation>Haga clic para añadir contactos</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/ui/MainWindow.cpp" line="191"/>
        <source>Remove %1</source>
        <translation>Eliminar %1</translation>
    </message>
    <message>
        <location filename="../src/ui/MainWindow.cpp" line="192"/>
        <source>Do you want to permanently remove %1?</source>
        <translation>¿Quiere eliminar permanentemente a %1?</translation>
    </message>
</context>
<context>
    <name>MessageDelegate</name>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="26"/>
        <source>%1 is offline</source>
        <extracomment>%1 nickname</extracomment>
        <translation>%1 está fuera de línea</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="135"/>
        <source>Copy ID</source>
        <translation>Copiar ID (identificador)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="135"/>
        <source>Copy Link</source>
        <translation>Copiar Enlace</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="140"/>
        <source>Open with Browser</source>
        <translation>Abrir con el Navegador</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="154"/>
        <source>Add as Contact</source>
        <translation>Añadir como Contacto</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="166"/>
        <source>Copy Message</source>
        <translation>Copiar mensaje</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="173"/>
        <source>Copy Selection</source>
        <translation>Copiar selección</translation>
    </message>
</context>
<context>
    <name>MessageDialogWrapper</name>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="8"/>
        <source>Remove %1</source>
        <translation>Eliminar %1</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="10"/>
        <source>Do you want to permanently remove %1?</source>
        <extracomment>%1 nickname</extracomment>
        <translation>¿Quiere eliminar permanentemente a %1?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="11"/>
        <source>This contact will no longer be able to message you, and will be notified about the removal. They may choose to send a new connection request.</source>
        <translation>Este contacto ya no podrá enviarle mensajes, y será notificado sobre la eliminación. Pueden elegir enviar una nueva solicitud de conexión.</translation>
    </message>
</context>
<context>
    <name>NetworkSetupWizard</name>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="100"/>
        <source>This computer&apos;s Internet connection is free of obstacles. I would like to connect directly to the Tor network.</source>
        <translation>La conexión a Internet de este equipo está libre de obstáculos. Me gustaría conectar directamente a la red Tor.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="107"/>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="124"/>
        <source>This computer&apos;s Internet connection is censored, filtered, or proxied. I need to configure network settings.</source>
        <translation>La conexión a Internet de este equipo está censurada, filtrada, o proxyficada. Necesito configurar las preferencias de red.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="131"/>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
</context>
<context>
    <name>OfflineStateItem</name>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="107"/>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="115"/>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="143"/>
        <source>Connection failed</source>
        <translation>Conexión fallida</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="169"/>
        <source>Connecting…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Conectando...</translation>
    </message>
</context>
<context>
    <name>OpenBrowserDialog</name>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="40"/>
        <source>&lt;b&gt;Warning!&lt;/b&gt; Opening links with your default browser will harm your security and anonymity.&lt;br&gt;&lt;br&gt;You can &lt;a href=&apos;.&apos;&gt;copy to the clipboard&lt;/a&gt; instead.</source>
        <translation>&lt;b&gt;¡Advertencia!&lt;/b&gt; Abrir enlaces con su navegador predeterminado perjudicará su seguridad y anonimato. &lt;br&gt;&lt;br&gt;En su lugar puede &lt;a href=&apos;.&apos;&gt;copiarlos al portapapeles&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="59"/>
        <source>Don&apos;t ask again for links from %1</source>
        <translation>No volver a preguntar por enlaces desde %1</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="65"/>
        <source>Don&apos;t ask again for any links (not recommended!)</source>
        <translation>No volver a preguntar por ningún enlace (¡no recomendado!)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="72"/>
        <source>Open Browser</source>
        <translation>Abrir Navegador</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="84"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="12"/>
        <source>Ricochet Preferences</source>
        <translation>Preferencias de Ricochet</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="41"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="vanished">Idioma</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="46"/>
        <source>Contacts</source>
        <translation>Contactos</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="51"/>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="56"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
</context>
<context>
    <name>QCocoaMenuItem</name>
    <message>
        <location filename="../src/ui/qml/MainWindow.qml" line="29"/>
        <source>Preference</source>
        <translation>Preferencia</translation>
    </message>
</context>
<context>
    <name>StartupStatusPage</name>
    <message>
        <location filename="../src/ui/qml/StartupStatusPage.qml" line="18"/>
        <source>The Tor process was not started successfully. This is most likely an installation or system error.</source>
        <translation>El proceso Tor no se inició con éxito. Lo más probable es que esto sea un error de instalación o de sistema.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/StartupStatusPage.qml" line="49"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>TorBootstrapStatus</name>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="17"/>
        <source>Connecting to the Tor network…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Conectando a la red Tor...</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="51"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="58"/>
        <source>Hide details</source>
        <translation>Ocultar detalles</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="58"/>
        <source>Show details</source>
        <translation>Mostrar detalles</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="70"/>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
</context>
<context>
    <name>TorConfigurationPage</name>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="73"/>
        <source>Does this computer need a proxy to access the internet?</source>
        <translation>¿Este equipo necesita un proxy para acceder a Internet?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="85"/>
        <source>Proxy type:</source>
        <translation>Tipo de proxy:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="90"/>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="92"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="107"/>
        <source>Address:</source>
        <translation>Dirección:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="116"/>
        <source>IP address or hostname</source>
        <translation>Dirección IP o nombre del equipo</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="119"/>
        <source>Port:</source>
        <translation>Puerto:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="130"/>
        <source>Username:</source>
        <translation>Nombre de usuario:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="140"/>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="150"/>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="143"/>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="160"/>
        <source>Does this computer&apos;s Internet connection go through a firewall that only allows connections to certain ports?</source>
        <translation>¿La conexión a Internet de este equipo va a través de un cortafuegos (firewall) que sólo permite conexiones a ciertos puertos?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="171"/>
        <source>Allowed ports:</source>
        <translation>Puertos permitidos:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="178"/>
        <source>Example: 80,443</source>
        <translation>Ejemplo: 80,443</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="189"/>
        <source>If this computer&apos;s Internet connection is censored, you will need to obtain and use bridge relays.</source>
        <translation>Si la conexión a Internet de este equipo está bajo censura, necesitará obtener y usar repetidores puente (bridge relays).</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="198"/>
        <source>Enter one or more bridge relays (one per line):</source>
        <translation>Introduzca uno o más repetidores puente (uno por línea):</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="213"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="220"/>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
</context>
<context>
    <name>TorPreferences</name>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="25"/>
        <source>Running:</source>
        <translation>Ejecutar:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="28"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="30"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="28"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="30"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <source>External</source>
        <translation>Externo</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="27"/>
        <source>Control connected:</source>
        <translation>Control conectado:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="29"/>
        <source>Circuits established:</source>
        <translation>Circuitos establecidos:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="31"/>
        <source>Hidden service:</source>
        <translation>Servicio oculto:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="32"/>
        <source>Online</source>
        <translation>En línea</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="32"/>
        <source>Offline</source>
        <translation>Fuera de línea</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="33"/>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="60"/>
        <source>Error: &lt;b&gt;%1&lt;/b&gt;</source>
        <extracomment>%1 is error message</extracomment>
        <translation>Error: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="76"/>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
</context>
<context>
    <name>TorStateWidget</name>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="9"/>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="20"/>
        <source>Connection failed</source>
        <translation>Conexión fallida</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="12"/>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="22"/>
        <source>Connecting…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Conectando...</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="25"/>
        <source>Connecting… (%1%)</source>
        <extracomment>%1 is progress percentage, e.g. 100</extracomment>
        <translation>Conectando... (%1%)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="32"/>
        <source>Online</source>
        <translation>En línea</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="34"/>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
</context>
</TS>
